==> percona-xtradb-cluster_8.0.34-26.orig.tar.gz: Percona-XtraDB-Cluster-8.0.34-26/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_alloc_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_alloc_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_asio_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_asio_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_atomic_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_atomic_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_config_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_config_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_datetime_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_datetime_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_deqmap_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_deqmap_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_digest_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_digest_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_gtid_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_gtid_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_histogram_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_histogram_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_mem_pool_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_mem_pool_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_net_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_net_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_progress_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_progress_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_rset_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_rset_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_stats_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_stats_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_string_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_string_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_string_utils_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_string_utils_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_tests++.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_tests++.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_thread_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_thread_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_uri_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_uri_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_utils_test++.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_utils_test++.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_vector_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_vector_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_vlq_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_vlq_test.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_DATE_TIME_POSIX_TIME_STD_CONFIG=1"
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "GALERA_HAVE_SSL"
  "GU_ASIO_TEST_CERT_DIR=\"/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/tests/conf\""
  "HAVE_ASIO_HPP"
  "HAVE_BOOST_SHARED_PTR_HPP"
  "HAVE_BYTESWAP_H"
  "HAVE_COMMON_H"
  "HAVE_CONFIG_H"
  "HAVE_ENDIAN_H"
  "HAVE_PSI_INTERFACE=1"
  "HAVE_STD_ARRAY"
  "HAVE_STD_UNORDERED_MAP"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "NDEBUG"
  "OPENSSL_HAS_SET_ECDH_AUTO"
  "PXC"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "percona-xtradb-cluster-galera"
  "percona-xtradb-cluster-galera/common"
  "percona-xtradb-cluster-galera/galera/src"
  "percona-xtradb-cluster-galera/galerautils/src"
  "percona-xtradb-cluster-galera/gcache/src"
  "percona-xtradb-cluster-galera/gcomm/src"
  "percona-xtradb-cluster-galera/gcs/src"
  "percona-xtradb-cluster-galera/wsrep/src"
  "extra/protobuf/protobuf-3.19.4/src"
  "percona-xtradb-cluster-galera/asio"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautilsxx.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_hw_crc32c.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_log.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-xtradb-cluster_8.0.39-30.orig.tar.gz: Percona-XtraDB-Cluster-8.0.39-30/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_alloc_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_alloc_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_asio_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_asio_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_atomic_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_atomic_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_config_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_config_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_datetime_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_datetime_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_deqmap_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_deqmap_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_digest_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_digest_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_gtid_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_gtid_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_histogram_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_histogram_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_mem_pool_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_mem_pool_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_net_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_net_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_progress_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_progress_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_rset_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_rset_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_stats_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_stats_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_string_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_string_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_string_utils_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_string_utils_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_tests++.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_tests++.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_thread_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_thread_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_uri_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_uri_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_utils_test++.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_utils_test++.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_vector_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_vector_test.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/gu_vlq_test.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/CMakeFiles/gu_tests++.dir/gu_vlq_test.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_BIND_GLOBAL_PLACEHOLDERS=1"
  "BOOST_DATE_TIME_POSIX_TIME_STD_CONFIG=1"
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "GALERA_HAVE_SSL"
  "GU_ASIO_TEST_CERT_DIR=\"/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/tests/certs\""
  "HAVE_ASIO_HPP"
  "HAVE_BOOST_SHARED_PTR_HPP"
  "HAVE_BYTESWAP_H"
  "HAVE_COMMON_H"
  "HAVE_CONFIG_H"
  "HAVE_ENDIAN_H"
  "HAVE_PSI_INTERFACE=1"
  "HAVE_STD_ARRAY"
  "HAVE_STD_UNORDERED_MAP"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "NDEBUG"
  "OPENSSL_HAS_SET_ECDH_AUTO"
  "PXC"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "_XOPEN_SOURCE=600"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "percona-xtradb-cluster-galera"
  "percona-xtradb-cluster-galera/common"
  "percona-xtradb-cluster-galera/galera/src"
  "percona-xtradb-cluster-galera/galerautils/src"
  "percona-xtradb-cluster-galera/gcache/src"
  "percona-xtradb-cluster-galera/gcomm/src"
  "percona-xtradb-cluster-galera/gcs/src"
  "percona-xtradb-cluster-galera/wsrep/src"
  "extra/protobuf/protobuf-24.4/src"
  "percona-xtradb-cluster-galera/asio"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautilsxx.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_hw_crc32c.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_log.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
